@@ -19,7 +19,7 @@ pub fn solve(input: &mut Input) -> Result<i32, String> {
 
 #[test]
 pub fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     let real_input = include_str!("day01_input.txt");
     test_part_one!(real_input => 280);
