@@ -34,8 +34,8 @@ pub fn solve(input: &mut Input) -> Result<u32, String> {
                 .ok_or("Invalid attribute value")?;
 
             let does_match = match (input.is_part_two(), attribute_name) {
-                (true, "cats") | (true, "trees") => desired_value < attribute_value,
-                (true, "pomeranians") | (true, "goldfish") => desired_value > attribute_value,
+                (true, "cats" | "trees") => desired_value < attribute_value,
+                (true, "pomeranians" | "goldfish") => desired_value > attribute_value,
                 _ => desired_value == attribute_value,
             };
             if !does_match {
@@ -50,7 +50,7 @@ pub fn solve(input: &mut Input) -> Result<u32, String> {
 
 #[test]
 pub fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     let real_input = include_str!("day16_input.txt");
     test_part_one!(real_input => 213);
