@@ -60,7 +60,7 @@ pub fn solve(input: &mut Input) -> Result<u32, String> {
 
 #[test]
 pub fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     let real_input = include_str!("day04_input.txt");
 
