@@ -53,7 +53,7 @@ pub fn solve(input: &mut Input) -> Result<u64, String> {
 
 #[test]
 pub fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     test_part_one!("ADVENT" => 6);
     test_part_one!("A(1x5)BC" => 7);
