@@ -277,7 +277,7 @@ pub fn solve(input: &mut Input) -> Result<u32, String> {
 
 #[test]
 pub fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     let example_input = "The first floor contains a promethium generator and a promethium-compatible microchip.
 The second floor contains a cobalt generator, a curium generator, a ruthenium generator, and a plutonium generator.
