@@ -20,7 +20,7 @@ pub fn solve(input: &mut Input) -> Result<u32, String> {
 
 #[test]
 pub fn tests() {
-    use crate::test_part_one;
+    use crate::input::test_part_one;
 
     let real_input = include_str!("day25_input.txt");
     test_part_one!(real_input => 196);
