@@ -33,7 +33,7 @@ pub fn solve(input: &mut Input) -> Result<u32, String> {
 
 #[test]
 fn test() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     test_part_one!("5 1 9 5\n7 5 3\n2 4 6 8" => 18);
     test_part_two!("5 9 2 8\n9 4 7 3\n3 8 6 5" => 9);
