@@ -116,7 +116,7 @@ pub fn solve(input: &mut Input) -> Result<usize, String> {
 
 #[test]
 fn test() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
     test_part_one!("12" => 3);
     test_part_one!("23" => 2);
     test_part_one!("1024" => 31);
