@@ -82,7 +82,7 @@ pub fn solve(input: &mut Input) -> Result<String, String> {
 
 #[test]
 fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     test_part_one!("9" => "5158916779".into());
     test_part_one!("5" => "0124515891".into());
