@@ -45,7 +45,7 @@ pub fn solve(input: &mut Input) -> Result<u64, String> {
 
 #[test]
 fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     test_part_one!(
             "#ip 0
