@@ -131,7 +131,7 @@ pub fn solve(input: &mut Input) -> Result<i32, String> {
 
 #[test]
 fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     test_part_one!("^WNE$" => 3);
     test_part_one!("^ENWWW(NEEE|SSE(EE|N))$" => 10);
