@@ -69,7 +69,7 @@ pub fn solve(input: &mut Input) -> Result<u64, String> {
 
 #[test]
 fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
     let input = include_str!("day21_input.txt");
     test_part_one!(input => 7_216_956);
     test_part_two!(input => 14_596_916);
