@@ -23,12 +23,13 @@ const fn is_compatible(region_type: RegionType, equipment: Equipment) -> bool {
     // In narrow regions, you can use the torch or neither tool. You cannot use the climbing gear (it's too bulky to fit).
     matches!(
         (region_type, equipment),
-        (RegionType::Rocky, Equipment::ClimbingGear)
-            | (RegionType::Rocky, Equipment::Torch)
-            | (RegionType::Wet, Equipment::ClimbingGear)
-            | (RegionType::Wet, Equipment::Neither)
-            | (RegionType::Narrow, Equipment::Torch)
-            | (RegionType::Narrow, Equipment::Neither)
+        (
+            RegionType::Rocky,
+            Equipment::ClimbingGear | Equipment::Torch
+        ) | (
+            RegionType::Wet,
+            Equipment::ClimbingGear | Equipment::Neither
+        ) | (RegionType::Narrow, Equipment::Torch | Equipment::Neither)
     )
 }
 
@@ -214,7 +215,7 @@ pub fn solve(input: &mut Input) -> Result<i32, String> {
 
 #[test]
 fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     test_part_one!("depth: 510\ntarget: 10,10" => 114);
     test_part_two!("depth: 510\ntarget: 10,10" => 45);
