@@ -137,7 +137,7 @@ fn part2_nth(input_string: &str, nth: u32) -> Result<(i64, i64), String> {
 
 #[test]
 pub fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
     let input = include_str!("day10_input.txt");
     test_part_one!(input => 319);
     test_part_two!(input => 517);
