@@ -105,7 +105,7 @@ pub fn solve(input: &mut Input) -> Result<i128, String> {
 
 #[test]
 pub fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     let input = include_str!("day22_input.txt");
     test_part_one!(input => 6526);
